@@ -1,13 +1,13 @@
 """userverse_python_client public API."""
 
-from typing import TYPE_CHECKING, Any
-
 from .clients.user import UverseUserClient
 from .clients.company import UverseCompanyClient
 from .clients.company_user_management import UverseCompanyUserManagementClient
+from .clients.company_user_roles_management import UverseCompanyUserRolesManagement
 
 __all__ = [
     "UverseUserClient",
     "UverseCompanyClient",
     "UverseCompanyUserManagementClient",
+    "UverseCompanyUserRolesManagement",
 ]
